files Package
=============

:mod:`files` Package
--------------------

.. automodule:: camelot.core.files
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`storage` Module
---------------------

.. automodule:: camelot.core.files.storage
    :members:
    :undoc-members:
    :show-inheritance:

